from django.test import TestCase
from selenium.webdriver import Chrome
from selenium.webdriver.common.by import By
from selenium.webdriver.common.action_chains import ActionChains


class LoginTestCase(TestCase):
    def setUp(self) -> None:
        self.driver = Chrome()
    
    def tearDown(self) -> None:
        self.driver.close()
    
    def test_log_in_as_admin(self):
        self.get_url('http://localhost:1026/auth/login/')
        
        self.fill_input_by_name('username', 'admin')
        self.fill_input_by_name('password', 'root')
        self.click_button()
        
        self.check_url('http://localhost:1026/articles/')
    
    def test_log_in_error(self):
        self.get_url('http://localhost:1026/auth/login/')

        self.fill_input_by_name('username', 'admindsf')
        self.fill_input_by_name('password', 'roodasfasdf')

        self.click_button()
        self.check_url('http://localhost:1026/auth/login/?next=')
        self.see_error_with_text('Пожалуйста, введите правильные имя пользователя и пароль. Оба поля могут быть чувствительны к регистру.')

    def click_button(self):
        button = self.driver.find_element(By.CLASS_NAME, 'btn')
        self.driver.implicitly_wait(10)
        ActionChains(self.driver).move_to_element(button).click(button).perform()

    def get_url(self, url):
        self.driver.get(url)

    def fill_input_by_name(self, name, text):
        self.driver.find_element(By.NAME, name).send_keys(text)

    def check_url(self, url):
        assert self.driver.current_url == url

    def see_error_with_text(self, text):
        error = self.driver.find_element(By.CLASS_NAME, 'alert-danger')
        assert error.text == text
