from django.test import TestCase
from web.models import Article
from accounts.models import User


class ArticleTestCase(TestCase):
    def setUp(self):
        admin = User.objects.create(username='admin', password='root')
        admin.is_superuser = True
        admin.save()
        
        self.client.login(username='admin', password='root')

        a1 = Article.objects.create(title='Test 1', text='Test text 1')
        a2 = Article.objects.create(title='Test 2', text='Test text 2')
        a3 = Article.objects.create(title='Test 3', text='Test text 3')

        self.articles = [a1, a2, a3]
    
    def test_update_article_success(self):
        article = self.articles[0]
        
        update_data = {'title': 'Article', 'text': 'article text'}
        
        article.title = update_data['title']
        article.text = update_data['text']
        
        article.save()
        article_from_db = Article.objects.get(id=article.id)
        
        assert article_from_db.title == update_data['title']
        assert article_from_db.text == update_data['text']
        
    def test_update_article_error(self):
        article = self.articles[0]
        
        update_data = {'title': 'Article', 'text': 'article text'}
        
        article.title = update_data['title']
        article.text = update_data['text']
        
        article_from_db = Article.objects.get(id=article.id)
        
        assert not article_from_db.title == update_data['title']
        assert not article_from_db.text == update_data['text']

    def test_create_article_success(self):
        data = {'title': 'title', 'text': 'text'}
        response = self.client.post('/api/article/', data=data)
        
        assert response.status_code == 201
        
        Article.objects.update(status='accepted')
        
        assert Article.objects.filter(title=data['title']).exists()
